==> debug-level-1.1.0.tgz: package/lib/Namespaces.js <==
"use strict";

function _createForOfIteratorHelper(o, allowArrayLike) { var it; if (typeof Symbol === "undefined" || o[Symbol.iterator] == null) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = o[Symbol.iterator](); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it["return"] != null) it["return"](); } finally { if (didErr) throw err; } } }; }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

/**
 * @license MIT
 * @copyright debug contributors, <commenthol@gmail.com>
 * @see https://github.com/visionmedia/debug
 */
var _require = require('./utils.js'),
    DEBUG = _require.DEBUG,
    INFO = _require.INFO,
    WARN = _require.WARN,
    ERROR = _require.ERROR,
    FATAL = _require.FATAL,
    OFF = _require.OFF;

var LEVELS = [DEBUG, INFO, WARN, ERROR, FATAL, OFF];
var LEVELS_REGEX = RegExp("^(".concat(LEVELS.join('|'), "):"), 'i');
module.exports = Namespaces;

function Namespaces(namespaces) {
  this.enable(namespaces);
}

Namespaces.prototype = {
  enable: function enable(namespaces) {
    this.skips = [];
    this.names = [];
    var splited = (typeof namespaces === 'string' ? namespaces : '').split(/[\s,]+/);

    var _iterator = _createForOfIteratorHelper(splited),
        _step;

    try {
      for (_iterator.s(); !(_step = _iterator.n()).done;) {
        var _namespace = _step.value;
        if (!_namespace) continue; // ignore empty strings

        var _this$_namespaceNLeve = this._namespaceNLevel(_namespace),
            namespace = _this$_namespaceNLeve.namespace,
            level = _this$_namespaceNLeve.level;

        if (namespace[0] === '-') {
          this.skips.push({
            re: new RegExp('^' + namespace.substr(1) + '$')
          });
        } else {
          this.names.push({
            re: new RegExp('^' + namespace + '$'),
            level: level
          });
        }
      } // sort names by levels

    } catch (err) {
      _iterator.e(err);
    } finally {
      _iterator.f();
    }

    this.names = this.names.sort(function (a, b) {
      return LEVELS.indexOf(a.level) - LEVELS.indexOf(b.level);
    });
  },

  /* c8 ignore next 3 */
  disable: function disable() {
    this.enable('');
  },
  isEnabled: function isEnabled(name, level) {
    if (name === '*') {
      return level || 'DEBUG';
    }

    if (!this.names.length) {
      return level;
    }

    var _iterator2 = _createForOfIteratorHelper(this.skips),
        _step2;

    try {
      for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
        var _skip = _step2.value;

        if (_skip.re.test(name)) {
          return;
        }
      }
    } catch (err) {
      _iterator2.e(err);
    } finally {
      _iterator2.f();
    }

    var _iterator3 = _createForOfIteratorHelper(this.names),
        _step3;

    try {
      for (_iterator3.s(); !(_step3 = _iterator3.n()).done;) {
        var _name = _step3.value;

        if (_name.re.test(name)) {
          return _name.level || level || 'DEBUG';
        }
      }
    } catch (err) {
      _iterator3.e(err);
    } finally {
      _iterator3.f();
    }
  },

  /**
   * @private
   */
  _namespaceNLevel: function _namespaceNLevel(_namespace) {
    var level = (LEVELS_REGEX.exec(_namespace) || [])[1];

    var namespace = _namespace.replace(LEVELS_REGEX, '').replace(/\*/g, '.*?');

    return {
      namespace: namespace,
      level: level
    };
  }
};

==> debug-level-2.0.2.tgz: package/lib/Namespaces.js <==
"use strict";

function _createForOfIteratorHelper(o, allowArrayLike) { var it; if (typeof Symbol === "undefined" || o[Symbol.iterator] == null) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = o[Symbol.iterator](); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it["return"] != null) it["return"](); } finally { if (didErr) throw err; } } }; }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

/**
 * @license MIT
 * @copyright debug contributors, <commenthol@gmail.com>
 * @see https://github.com/visionmedia/debug
 */
var _require = require('./utils.js'),
    TRACE = _require.TRACE,
    DEBUG = _require.DEBUG,
    INFO = _require.INFO,
    WARN = _require.WARN,
    ERROR = _require.ERROR,
    FATAL = _require.FATAL,
    OFF = _require.OFF;

var LEVELS = [TRACE, DEBUG, INFO, WARN, ERROR, FATAL, OFF];
var LEVELS_REGEX = RegExp("^(".concat(LEVELS.join('|'), "):"), 'i');
module.exports = Namespaces;

function Namespaces(namespaces) {
  this.enable(namespaces);
}

Namespaces.prototype = {
  enable: function enable(namespaces) {
    this.skips = [];
    this.names = [];
    var splited = (typeof namespaces === 'string' ? namespaces : '').split(/[\s,]+/);

    var _iterator = _createForOfIteratorHelper(splited),
        _step;

    try {
      for (_iterator.s(); !(_step = _iterator.n()).done;) {
        var _namespace = _step.value;
        if (!_namespace) continue; // ignore empty strings

        var _this$_namespaceNLeve = this._namespaceNLevel(_namespace),
            namespace = _this$_namespaceNLeve.namespace,
            level = _this$_namespaceNLeve.level;

        if (namespace[0] === '-') {
          this.skips.push({
            re: new RegExp('^' + namespace.substr(1) + '$')
          });
        } else {
          this.names.push({
            re: new RegExp('^' + namespace + '$'),
            level: level
          });
        }
      } // sort names by levels

    } catch (err) {
      _iterator.e(err);
    } finally {
      _iterator.f();
    }

    this.names = this.names.sort(function (a, b) {
      return LEVELS.indexOf(a.level) - LEVELS.indexOf(b.level);
    });
  },

  /* c8 ignore next 3 */
  disable: function disable() {
    this.enable('');
  },
  isEnabled: function isEnabled(name, level) {
    if (name === '*') {
      return level || 'DEBUG';
    }

    if (!this.names.length) {
      return level;
    }

    var _iterator2 = _createForOfIteratorHelper(this.skips),
        _step2;

    try {
      for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
        var _skip = _step2.value;

        if (_skip.re.test(name)) {
          return;
        }
      }
    } catch (err) {
      _iterator2.e(err);
    } finally {
      _iterator2.f();
    }

    var _iterator3 = _createForOfIteratorHelper(this.names),
        _step3;

    try {
      for (_iterator3.s(); !(_step3 = _iterator3.n()).done;) {
        var _name = _step3.value;

        if (_name.re.test(name)) {
          return _name.level || level || 'DEBUG';
        }
      }
    } catch (err) {
      _iterator3.e(err);
    } finally {
      _iterator3.f();
    }
  },

  /**
   * @private
   */
  _namespaceNLevel: function _namespaceNLevel(_namespace) {
    var level = (LEVELS_REGEX.exec(_namespace) || [])[1];

    var namespace = _namespace.replace(LEVELS_REGEX, '').replace(/\*/g, '.*?');

    return {
      namespace: namespace,
      level: level
    };
  }
};
